aboutsummaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorMax Horn2011-06-03 23:30:55 +0200
committerMax Horn2011-06-04 11:55:56 +0200
commit91b889e2d36baf8a8e1f56f05f4d063e5ae79849 (patch)
tree556b640ec36bb408f74f0a39845bcb306d5d1a14 /common
parent4b95cf5d1a1ac4fbf91544ef6ab1493ad9dbb775 (diff)
downloadscummvm-rg350-91b889e2d36baf8a8e1f56f05f4d063e5ae79849.tar.gz
scummvm-rg350-91b889e2d36baf8a8e1f56f05f4d063e5ae79849.tar.bz2
scummvm-rg350-91b889e2d36baf8a8e1f56f05f4d063e5ae79849.zip
COMMON: Rename kFeatureCursorHasPalette -> kFeatureCursorPalette
Diffstat (limited to 'common')
-rw-r--r--common/system.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/common/system.h b/common/system.h
index ad706b51fd..67f7ac84da 100644
--- a/common/system.h
+++ b/common/system.h
@@ -168,7 +168,7 @@ public:
* To enable the cursor palette call "disableCursorPalette" with false.
* @see disableCursorPalette
*/
- kFeatureCursorHasPalette,
+ kFeatureCursorPalette,
/**
* Set to true if the overlay pixel format has an alpha channel.
@@ -776,22 +776,22 @@ public:
* The palette entries from 'start' till (start+num-1) will be replaced - so
* a full palette update is accomplished via start=0, num=256.
*
* Backends which implement it should have kFeatureCursorHasPalette flag set
*
* @see setPalette
- * @see kFeatureCursorHasPalette
+ * @see kFeatureCursorPalette
*/
virtual void setCursorPalette(const byte *colors, uint start, uint num) {}
/**
* Disable or enable cursor palette.
*
* Backends which implement it should have kFeatureCursorHasPalette flag set
*
* @param disable True to disable, false to enable.
*
* @see setPalette
- * @see kFeatureCursorHasPalette
+ * @see kFeatureCursorPalette
*/
virtual void disableCursorPalette(bool disable) {}
@@ -776,22 +776,22 @@ public:
* a full palette update is accomplished via start=0, num=256.
*
- * Backends which implement it should have kFeatureCursorHasPalette flag set
+ * Backends which implement it should have kFeatureCursorPalette flag set
*
* @see setPalette
@@ -776,22 +776,22 @@ public:
* Disable or enable cursor palette.
*
- * Backends which implement it should have kFeatureCursorHasPalette flag set
+ * Backends which implement it should have kFeatureCursorPalette flag set
*
* @param disable True to disable, false to enable.